aboutsummaryrefslogtreecommitdiff
path: root/src/genTestImgs.sh
diff options
context:
space:
mode:
Diffstat (limited to 'src/genTestImgs.sh')
-rwxr-xr-xsrc/genTestImgs.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/genTestImgs.sh b/src/genTestImgs.sh
index 1198a60..21b001b 100755
--- a/src/genTestImgs.sh
+++ b/src/genTestImgs.sh
@@ -2,10 +2,10 @@
set -e
#generate tol.json from tol.txt
-cat tol.txt | ./txtTreeToJSON.py > tol.json
+cat tolData.txt | ./txtTreeToJSON.py > tolData.json
-#reads through tol.json, gets names, and generates image for each name
-cat tol.json | \
+#reads through tolData.json, gets names, and generates image for each name
+cat tolData.json | \
gawk 'match ($0, /"name"\s*:\s*"([^"]*)"/, arr) {print arr[1]}' | \
while read; do
convert -size 200x200 xc:khaki +repage \